==> react-image-annotate-1.0.15.tgz: package/Sidebar/index.js <==
import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import TaskDescription from "../TaskDescriptionSidebarBox";
import ImageSelector from "../ImageSelectorSidebarBox";
import RegionSelector from "../RegionSelectorSidebarBox";
import History from "../HistorySidebarBox";
import DebugBox from "../DebugSidebarBox";
import TagsSidebarBox from "../TagsSidebarBox";
import KeyframesSelector from "../KeyframesSelectorSidebarBox";
import Shortcuts from "../Shortcuts";
var useStyles = makeStyles({});
var emptyArr = [];
export var Sidebar = function Sidebar(_ref) {
  var debug = _ref.debug,
      taskDescription = _ref.taskDescription,
      keyframes = _ref.keyframes,
      images = _ref.images,
      regions = _ref.regions,
      history = _ref.history,
      labelImages = _ref.labelImages,
      currentImage = _ref.currentImage,
      currentVideoTime = _ref.currentVideoTime,
      imageClsList = _ref.imageClsList,
      imageTagList = _ref.imageTagList,
      onChangeImage = _ref.onChangeImage,
      onSelectRegion = _ref.onSelectRegion,
      onSelectImage = _ref.onSelectImage,
      onChangeRegion = _ref.onChangeRegion,
      onDeleteRegion = _ref.onDeleteRegion,
      _onRestoreHistory = _ref.onRestoreHistory,
      onChangeVideoTime = _ref.onChangeVideoTime,
      onDeleteKeyframe = _ref.onDeleteKeyframe,
      onShortcutActionDispatched = _ref.onShortcutActionDispatched;
  var classes = useStyles();
  if (!regions) regions = emptyArr;
  return React.createElement("div", null, debug && React.createElement(DebugBox, {
    state: debug,
    lastAction: debug.lastAction
  }), taskDescription && (taskDescription || "").length > 1 && React.createElement(TaskDescription, {
    description: taskDescription
  }), labelImages && React.createElement(TagsSidebarBox, {
    currentImage: currentImage,
    imageClsList: imageClsList,
    imageTagList: imageTagList,
    onChangeImage: onChangeImage,
    expandedByDefault: true
  }), images && images.length > 1 && React.createElement(ImageSelector, {
    onSelect: onSelectImage,
    images: images
  }), React.createElement(RegionSelector, {
    regions: regions,
    onSelectRegion: onSelectRegion,
    onChangeRegion: onChangeRegion,
    onDeleteRegion: onDeleteRegion
  }), keyframes && React.createElement(KeyframesSelector, {
    currentVideoTime: currentVideoTime,
    keyframes: keyframes,
    onChangeVideoTime: onChangeVideoTime,
    onDeleteKeyframe: onDeleteKeyframe
  }), React.createElement(History, {
    history: history,
    onRestoreHistory: function onRestoreHistory() {
      return _onRestoreHistory();
    }
  }));
};
export default Sidebar;

==> react-image-annotate-1.3.2.tgz: package/Sidebar/index.js <==
import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import TaskDescription from "../TaskDescriptionSidebarBox";
import ImageSelector from "../ImageSelectorSidebarBox";
import RegionSelector from "../RegionSelectorSidebarBox";
import History from "../HistorySidebarBox";
import DebugBox from "../DebugSidebarBox";
import TagsSidebarBox from "../TagsSidebarBox";
import KeyframesSelector from "../KeyframesSelectorSidebarBox";
import Shortcuts from "../Shortcuts";
var useStyles = makeStyles({});
var emptyArr = [];
export var Sidebar = function Sidebar(_ref) {
  var debug = _ref.debug,
      taskDescription = _ref.taskDescription,
      keyframes = _ref.keyframes,
      images = _ref.images,
      regions = _ref.regions,
      history = _ref.history,
      labelImages = _ref.labelImages,
      currentImage = _ref.currentImage,
      currentVideoTime = _ref.currentVideoTime,
      imageClsList = _ref.imageClsList,
      imageTagList = _ref.imageTagList,
      onChangeImage = _ref.onChangeImage,
      onSelectRegion = _ref.onSelectRegion,
      onSelectImage = _ref.onSelectImage,
      onChangeRegion = _ref.onChangeRegion,
      onDeleteRegion = _ref.onDeleteRegion,
      _onRestoreHistory = _ref.onRestoreHistory,
      onChangeVideoTime = _ref.onChangeVideoTime,
      onDeleteKeyframe = _ref.onDeleteKeyframe,
      onShortcutActionDispatched = _ref.onShortcutActionDispatched;
  var classes = useStyles();
  if (!regions) regions = emptyArr;
  return /*#__PURE__*/React.createElement("div", null, debug && /*#__PURE__*/React.createElement(DebugBox, {
    state: debug,
    lastAction: debug.lastAction
  }), taskDescription && (taskDescription || "").length > 1 && /*#__PURE__*/React.createElement(TaskDescription, {
    description: taskDescription
  }), labelImages && /*#__PURE__*/React.createElement(TagsSidebarBox, {
    currentImage: currentImage,
    imageClsList: imageClsList,
    imageTagList: imageTagList,
    onChangeImage: onChangeImage,
    expandedByDefault: true
  }), images && images.length > 1 && /*#__PURE__*/React.createElement(ImageSelector, {
    onSelect: onSelectImage,
    images: images
  }), /*#__PURE__*/React.createElement(RegionSelector, {
    regions: regions,
    onSelectRegion: onSelectRegion,
    onChangeRegion: onChangeRegion,
    onDeleteRegion: onDeleteRegion
  }), keyframes && /*#__PURE__*/React.createElement(KeyframesSelector, {
    currentVideoTime: currentVideoTime,
    keyframes: keyframes,
    onChangeVideoTime: onChangeVideoTime,
    onDeleteKeyframe: onDeleteKeyframe
  }), /*#__PURE__*/React.createElement(History, {
    history: history,
    onRestoreHistory: function onRestoreHistory() {
      return _onRestoreHistory();
    }
  }));
};
export default Sidebar;
